// Copyright 2018 The Go Authors. All rights reserved.
// Use of this source code is governed by a BSD-style
// license that can be found in the LICENSE file.

syntax = "proto3";

package goproto.protoc.proto3;

option go_package = "google.golang.org/protobuf/cmd/protoc-gen-go/testdata/proto3";

enum Enum {
  ZERO = 0;
  ONE = 1;
  TWO = 2;
}
