// Copyright 2018 The Go Authors. All rights reserved.
// Use of this source code is governed by a BSD-style
// license that can be found in the LICENSE file.

syntax = "proto2";

package goproto.protoc.import_public.sub;

option go_package = "google.golang.org/protobuf/cmd/protoc-gen-go/testdata/import_public/sub";

message M2 {
}
